summaryrefslogtreecommitdiffstats
path: root/iso/libisofs/iso_fs.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commitc5bf17eba3afebfcf37e27b4d91d99ff44b94e28 (patch)
tree2db956c83063bfa5733f7f3ed0399970d7ab7280 /iso/libisofs/iso_fs.h
parentacd0828c7a0c5d67f4474a82af93e5ff52cfb9dc (diff)
downloadkrusader-c5bf17eba3afebfcf37e27b4d91d99ff44b94e28.tar.gz
krusader-c5bf17eba3afebfcf37e27b4d91d99ff44b94e28.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/krusader@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'iso/libisofs/iso_fs.h')
-rw-r--r--iso/libisofs/iso_fs.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/iso/libisofs/iso_fs.h b/iso/libisofs/iso_fs.h
index b726b9f..43353b0 100644
--- a/iso/libisofs/iso_fs.h
+++ b/iso/libisofs/iso_fs.h
@@ -131,13 +131,13 @@ struct hs_primary_descriptor {
char root_directory_record [ISODCL (181, 214)]; /* 9.1 */
};
/* We use this to help us look up the tqparent inode numbers. */
struct iso_path_table{
char name_len[1]; /* 711 */
char ext_attr_length[1]; /* 711 */
char extent[4]; /* 731 */
- char tqparent[2]; /* 721 */
+ char parent[2]; /* 721 */
char name[1];
};
@@ -131,13 +131,13 @@ struct hs_primary_descriptor {
char root_directory_record [ISODCL (181, 214)]; /* 9.1 */
};
-/* We use this to help us look up the tqparent inode numbers. */
+/* We use this to help us look up the parent inode numbers. */
struct iso_path_table{
char name_len[1]; /* 711 */